@@ -17,7 +17,7 @@ __license__ = "MIT"
 
 from typing import TYPE_CHECKING
 
-from mojo.xmods.landscaping.client.clientcoordinatorcouplingbase import ClientCoordinatorCouplingBase
+from mojo.landscaping.client.clientcoordinatorcouplingbase import ClientCoordinatorCouplingBase
 
 from mojo.interop.clients.constants import INTEGRATION_CLASS_FOR_OSX_CLIENT
 from mojo.interop.clients.osx.osxclientcoordinator import OsxClientCoordinator
@@ -31,7 +31,7 @@ class OsxClientCoordinatorCoupling(ClientCoordinatorCouplingBase):
     COORDINATOR_TYPE = OsxClientCoordinator
 
     integration_root: str = "apod"
-    integration_section: str = "devices"
+    integration_section: str = "clients"
     integration_leaf: str = "deviceType"
     integration_class: str = INTEGRATION_CLASS_FOR_OSX_CLIENT
 
