@@ -19,7 +19,7 @@ __license__ = "MIT"
 from typing import TYPE_CHECKING
 
 from mojo.interop.clusters.constants import INTEGRATION_CLASS_FOR_RASPBERRYPI_NODE
-from mojo.xmods.landscaping.cluster.nodecoordinatorcouplingbase import NodeCoordinatorCouplingBase
+from mojo.landscaping.cluster.nodecoordinatorcouplingbase import NodeCoordinatorCouplingBase
 
 
 class PiNodeCoordinatorCoupling(NodeCoordinatorCouplingBase):
@@ -27,9 +27,6 @@ class PiNodeCoordinatorCoupling(NodeCoordinatorCouplingBase):
         The LinuxClientCoordinatorCoupling handle the requirement registration for the Linux coordinator.
     """
 
-    integration_root: str = "apod"
-    integration_section: str = "devices"
-    integration_leaf: str = "deviceType"
     integration_class: str = INTEGRATION_CLASS_FOR_RASPBERRYPI_NODE
 
     def __init__(self, *args, **kwargs):
