@@ -25,6 +25,8 @@ import stat
 import threading
 import time
 
+from datetime import datetime, timedelta
+
 import paramiko
 
 from mojo.waiting.waitmodel import TimeoutContext
@@ -32,8 +34,8 @@ from mojo.waiting.waitmodel import TimeoutContext
 from mojo.errors.exceptions import ConfigurationError, NotOverloadedError, SemanticError
 
 from mojo.xmods.aspects import ActionPattern, AspectsCmd, LoggingPattern, DEFAULT_CMD_ASPECTS
-from mojo.xmods.credentials.sshcredential import SshCredential
-from mojo.xmods.interfaces.isystemcontext import ISystemContext
+from mojo.credentials.sshcredential import SshCredential
+from mojo.interfaces.isystemcontext import ISystemContext
 from mojo.xmods.xformatting import indent_lines
 from mojo.xmods.xlogging.scopemonitoring import MonitoredScope
 
@@ -269,37 +271,66 @@ class SshBase(ISystemContext):
         cl_keypasswd = self._keypasswd
         cl_allow_agent = self._allow_agent
 
-        if session_user is not None:
-            if session_user not in self._users:
-                errmsg_list = [
-                    "No credentials found for the specified user '%s'." % session_user
-                ]
-                errmsg = os.linesep.join(errmsg_list)
-                raise ConfigurationError(errmsg) from None
+        now_time = datetime.now()
+        begin_time = now_time
+        end_time = begin_time + timedelta(seconds=self._aspects.connection_timeout)
 
-            user_creds = self._users[session_user]
+        connection_interval = self._aspects.connection_interval
+        allowed_connection_exceptions = self._aspects.allowed_connection_exceptions
 
-            cl_username = user_creds["username"]
-            cl_password = user_creds["password"]
-            cl_keyfile = user_creds["keyfile"]
-            cl_keypasswd = user_creds["keypasswd"]
-            cl_allow_agent = user_creds["allow_agent"]
+        while now_time < end_time:
 
-        pkey = None
-        if cl_keyfile is not None:
-            cl_keyfile = os.path.expanduser(os.path.expandvars(cl_keyfile))
-            pkey = paramiko.RSAKey.from_private_key_file(cl_keyfile, password=cl_keypasswd)
+            try:
 
-        ssh_client = paramiko.SSHClient()
-        ssh_client.set_missing_host_key_policy(paramiko.AutoAddPolicy())
+                if session_user is not None:
+                    if session_user not in self._users:
+                        errmsg_list = [
+                            "No credentials found for the specified user '%s'." % session_user
+                        ]
+                        errmsg = os.linesep.join(errmsg_list)
+                        raise ConfigurationError(errmsg) from None
+
+                    user_creds = self._users[session_user]
+
+                    cl_username = user_creds["username"]
+                    cl_password = user_creds["password"]
+                    cl_keyfile = user_creds["keyfile"]
+                    cl_keypasswd = user_creds["keypasswd"]
+                    cl_allow_agent = user_creds["allow_agent"]
+
+                pkey = None
+                if cl_keyfile is not None:
+                    cl_keyfile = os.path.expanduser(os.path.expandvars(cl_keyfile))
+                    pkey = paramiko.RSAKey.from_private_key_file(cl_keyfile, password=cl_keypasswd)
+
+                ssh_client = paramiko.SSHClient()
+                ssh_client.set_missing_host_key_policy(paramiko.AutoAddPolicy())
+
+                if self._jump is not None:
+                    proxy = paramiko.ProxyCommand(self._jump)
+                    ssh_client.connect(self._ipaddr, port=self._port, username=cl_username, password=cl_password,
+                                    pkey=pkey, allow_agent=cl_allow_agent, sock = proxy)
+                else:
+                    ssh_client.connect(self._ipaddr, port=self._port, username=cl_username, password=cl_password,
+                                    pkey=pkey, allow_agent=cl_allow_agent)
+                
+                break
+
+            except BaseException as cerr:
+                extype = type(cerr)
+
+                if len(allowed_connection_exceptions) > 0 and extype in allowed_connection_exceptions:
+                    errmsg = f"SSH connection attempt failed for host={self._ipaddr} begin={begin_time} end={now_time} now={now_time}."
+                    logger.error(errmsg)
+
+                    now_time = datetime.now()
+                    if now_time > end_time:
+                        raise ConnectionError(errmsg) from cerr
+                    else:
+                        time.sleep(connection_interval)
+                else:
+                    raise # If the exception we got is not an allowed type, re-raise it
 
-        if self._jump is not None:
-            proxy = paramiko.ProxyCommand(self._jump)
-            ssh_client.connect(self._ipaddr, port=self._port, username=cl_username, password=cl_password,
-                               pkey=pkey, allow_agent=cl_allow_agent, sock = proxy)
-        else:
-            ssh_client.connect(self._ipaddr, port=self._port, username=cl_username, password=cl_password,
-                               pkey=pkey, allow_agent=cl_allow_agent)
 
         return ssh_client
 
@@ -316,15 +347,13 @@ class SshBase(ISystemContext):
 
         if not self._primitive:
             transport = ssh_client.get_transport()
+    
+            sftp = paramiko.SFTPClient.from_transport(transport)
             try:
-
-                sftp = paramiko.SFTPClient.from_transport(transport)
-                try:
-                    dir_info = sftp_list_directory(sftp, root_dir, self.lookup_user_by_uid, self.lookup_group_by_uid)
-                finally:
-                    sftp.close()
+                dir_info = sftp_list_directory(sftp, root_dir, self.lookup_user_by_uid, self.lookup_group_by_uid)
             finally:
-                transport.close()
+                sftp.close()
+            
         else:
             dir_info = primitive_list_directory(ssh_client, root_dir)
 
@@ -337,17 +366,19 @@ class SshBase(ISystemContext):
         exists = False
 
         if not self._primitive:
+
             transport = ssh_client.get_transport()
+        
+            sftp = paramiko.SFTPClient.from_transport(transport)
             try:
-                sftp = paramiko.SFTPClient.from_transport(transport)
-                try:
-                    fsresult = sftp.stat(remotedir)
-                    if fsresult.st_mode | stat.S_IFDIR:
-                        exists = True
-                finally:
-                    sftp.close()
+                fsresult = sftp.stat(remotedir)
+                if fsresult.st_mode | stat.S_IFDIR:
+                    exists = True
+            except IOError:
+                exists = False
             finally:
-                transport.close()
+                sftp.close()
+
         else:
             primitive_directory_exists(ssh_client, remotedir)
 
@@ -367,20 +398,35 @@ class SshBase(ISystemContext):
 
         if not self._primitive:
             transport = ssh_client.get_transport()
-            try:
 
-                sftp = paramiko.SFTPClient.from_transport(transport)
-                try:
-                    dir_info = sftp_list_tree(sftp, root_dir, self.lookup_user_by_uid, self.lookup_group_by_uid, max_depth=depth)
-                finally:
-                    sftp.close()
+            sftp = paramiko.SFTPClient.from_transport(transport)
+            try:
+                dir_info = sftp_list_tree(sftp, root_dir, self.lookup_user_by_uid, self.lookup_group_by_uid, max_depth=depth)
             finally:
-                transport.close()
+                sftp.close()
+
         else:
             dir_info = primitive_list_tree(ssh_client, root_dir, max_depth=depth)
 
         return dir_info
 
+    def _get_home_directory(self, aspects: Optional[AspectsCmd] = None) -> str:
+        """
+            Private method that handles the getting of the home directory for the credential account from a remote machine.
+
+            :param aspects: The run aspects to use when running the command.
+
+            :returns: The remote home directory
+        """
+        home_dir = None
+
+        home_cmd = 'echo "$HOME"'
+        status, stdout, stderr = self.run_cmd(home_cmd, aspects=aspects)
+        if status == 0:
+            home_dir = stdout.strip()
+        
+        return home_dir
+
     def _log_command_result(self, command: str, status: int, stdout: str, stderr: str, exp_status: Union[int, Sequence[int]], logging_pattern: LoggingPattern):
         """
             Private method that handles the logging of command results based on the expected status and logging pattern
@@ -553,16 +599,16 @@ class SshBase(ISystemContext):
 
         if not self._primitive:
             transport = ssh_client.get_transport()
+
+            sftp = paramiko.SFTPClient.from_transport(transport)
             try:
-                sftp = paramiko.SFTPClient.from_transport(transport)
-                try:
-                    fsresult = sftp.stat(remotepath)
-                    if not (fsresult.st_mode | stat.S_IFDIR):
-                        exists = True
-                finally:
-                    sftp.close()
+                fsresult = sftp.stat(remotepath)
+                if not (fsresult.st_mode | stat.S_IFDIR):
+                    exists = True
+            except FileNotFoundError as ferr:
+                exists = False
             finally:
-                transport.close()
+                sftp.close()
         else:
             exists = primitive_file_exists(ssh_client, remotepath)
 
@@ -574,14 +620,13 @@ class SshBase(ISystemContext):
         """
         if not self._primitive:
             transport = ssh_client.get_transport()
+            
+            sftp = paramiko.SFTPClient.from_transport(transport)
             try:
-                sftp = paramiko.SFTPClient.from_transport(transport)
-                try:
-                    sftp.get(remotepath, localpath)
-                finally:
-                    sftp.close()
+                sftp.get(remotepath, localpath)
             finally:
-                transport.close()
+                sftp.close()
+
         else:
             primitive_file_pull(ssh_client, remotepath, localpath)
 
@@ -593,14 +638,13 @@ class SshBase(ISystemContext):
         """
         if not self._primitive:
             transport = ssh_client.get_transport()
+            
+            sftp = paramiko.SFTPClient.from_transport(transport)
             try:
-                sftp = paramiko.SFTPClient.from_transport(transport)
-                try:
-                    sftp.put(localpath, remotepath)
-                finally:
-                    sftp.close()
+                sftp.put(localpath, remotepath)
             finally:
-                transport.close()
+                sftp.close()
+            
         else:
             primitive_file_push(ssh_client, localpath, remotepath)
 
