@@ -33,25 +33,30 @@ import traceback
 from pprint import pformat
 
 from dataclasses import dataclass
-from logging.handlers import WatchedFileHandler
+from datetime import datetime
+from logging import FileHandler
 
 from uuid import uuid4
 
 from mojo.errors.exceptions import NotOverloadedError, SemanticError
+from mojo.errors.xtraceback import create_traceback_detail, format_traceback_detail
 
+from mojo.results.model.resultcode import ResultCode
+from mojo.results.model.resulttype import ResultType
 from mojo.results.model.progressinfo import ProgressInfo, ProgressType
 from mojo.results.model.progresscode import ProgressCode
+from mojo.results.model.taskingresult import TaskingResult
 
-from mojo.xmods.xformatting import indent_lines
+from mojo.xmods.xdatetime import format_datetime_with_fractional
+from mojo.xmods.xformatting import indent_lines_list
 from mojo.xmods.ximport import import_by_name
 from mojo.xmods.jsos import CHAR_RECORD_SEPERATOR
 
-from mojo.interop.protocols.tasker.taskingresult import TaskingResult
 from mojo.interop.protocols.tasker.taskeraspects import TaskerAspects, DEFAULT_TASKER_ASPECTS
 
 
-def instantiate_tasking(module_name: str, tasking_name: str, task_id: str, parent_id: str, logdir: str, logfile: str,
-                        log_level: int, notify_url: Optional[str], notify_headers: Optional[Dict[str, str]],
+def instantiate_tasking(worker: str, module_name: str, tasking_name: str, tasking_id: str, parent_id: str, output_dir: str,
+                        logdir: str, logfile: str, log_level: int, notify_url: Optional[str], notify_headers: Optional[Dict[str, str]],
                         aspects: Optional[TaskerAspects] = DEFAULT_TASKER_ASPECTS):
 
     logger = None
@@ -61,15 +66,21 @@ def instantiate_tasking(module_name: str, tasking_name: str, task_id: str, paren
 
     if hasattr(module, tasking_name):
 
-        log_handler = WatchedFileHandler(logfile)
-        logging.basicConfig(format=logging.BASIC_FORMAT, level=log_level, handlers=[log_handler])
+        logging.basicConfig(format=logging.BASIC_FORMAT, level=log_level)
 
-        logger = logging.getLogger("tasker-server")
+        log_handler = FileHandler(logfile)
+        log_handler.setLevel(log_level)
+        
+        logger = logging.getLogger("TASKING")
+        logger.addHandler(log_handler)
 
         tasking_type: Type[Tasking] = getattr(module, tasking_name)
 
-        tasking = tasking_type(task_id=task_id, parent_id=parent_id, logdir=logdir, logfile=logfile, logger=logger,
-                               notify_url=notify_url, notify_headers=notify_headers, aspects=aspects)
+        logger.info(f"Creating tasking module_name={module_name} tasking_name={tasking_name}")
+
+        tasking = tasking_type(worker=worker, tasking_id=tasking_id, parent_id=parent_id, output_dir=output_dir, 
+                               logdir=logdir, logfile=logfile, logger=logger, notify_url=notify_url,
+                               notify_headers=notify_headers, aspects=aspects)
 
     return tasking
 
@@ -103,15 +114,20 @@ class Tasking:
     """
     """
 
-    def __init__(self, task_id: str, parent_id: str, logdir: str, logfile: str, logger: logging.Logger, 
-                 notify_url: Optional[str] = None, notify_headers: Optional[dict] = None,
+    PREFIX = "tasking"
+
+    def __init__(self, worker: str, tasking_id: str, parent_id: str, output_dir: str, logdir: str,
+                 logfile: str, logger: logging.Logger, notify_url: Optional[str] = None,
+                 notify_headers: Optional[dict] = None,
                  aspects: Optional[TaskerAspects] = DEFAULT_TASKER_ASPECTS):
 
-        self._task_id = task_id
-        if self._task_id is None:
-            self._task_id = str(uuid4())
+        self._worker = worker
+        self._tasking_id = tasking_id
+        if self._tasking_id is None:
+            self._tasking_id = str(uuid4())
 
         self._parent_id = parent_id
+        self._output_dir = output_dir
         self._logdir = logdir
         self._logfile = logfile
         self._logger = logger
@@ -139,7 +155,6 @@ class Tasking:
         # The following variables are shared between process but must be updated in the parent process
         # when progress or state comes back from the child process
         self._result = None
-        self._exception = None
 
         # The following variables are used by the task process state
         self._current_progress = None
@@ -198,6 +213,14 @@ class Tasking:
         """
         return
 
+    def create_tasking_result(self, tasking_id: str, tasking_name: str, parent_id: str, prefix: str) -> TaskingResult:
+        """
+            Called to create the 'TaskingResult' object and can be overloaded by Tasking(s) to create a custom derived
+            'TaskingResult' type.
+        """
+        tresult = TaskingResult(tasking_id, tasking_name, parent_id, self._worker, prefix=prefix)
+        return tresult
+
     def execute(self, progress_queue: multiprocessing.JoinableQueue, kwparams: dict):
         """
             The `execute` method is called by the tasking service in order to trigger the execution
@@ -216,20 +239,22 @@ class Tasking:
 
         return
 
-    def evaluate_results(self) -> int:
+    def evaluate_results(self):
         """
             The `evaluate_results` method is called in order to process information to
             create a final status code for the given tasking.
 
             :returns: Returns the 'result_code' that is written into the tasking result.
         """
-        return 0
+        return
 
     def finalize(self):
         """
             The `finalize` method is called in order to provide an opportunity for a tasking
             to finalize execution and cleanup resources as required.
         """
+        self.result.finalize()
+
         finalize_msg = self.format_finalize_message()
         self._logger.info(finalize_msg)
         return
@@ -245,20 +270,22 @@ class Tasking:
             Formats the tasking 'BEGIN' log message.
         """
         
+        start_fmt = format_datetime_with_fractional(self._result.start)
+
         begin_msg_lines = [
             f"------------------------------- TASKING BEGUN -------------------------------",
-            f"  TASK_NAME: {self._result.task_name}",
-            f"    TASK_ID: {self._result.task_id}",
-            f"  PARENT_ID: {self._result.parent_id}",
+            f"  TASK_NAME: {self._result.name}",
+            f"    TASK_ID: {self._result.inst_id}",
+            f"  PARENT_ID: {self._result.parent_inst}",
             f"     LOGDIR: {self._logdir}",
-            f"      START: {self._result.start}"
+            f"      START: {start_fmt}"
         ]
 
-        kwparams_lines = pformat(kwparams, indent=4, width=200)
-        kwparams_lines = indent_lines(kwparams_lines, level=1, indent=10)
+        kwparams_lines = pformat(kwparams, indent=4, width=200).splitlines(False)
+        kwparams_lines = indent_lines_list(kwparams_lines, level=1, indent=10)
 
         begin_msg_lines.append("  KWPARAMS:")
-        begin_msg_lines.append(kwparams_lines)
+        begin_msg_lines.extend(kwparams_lines)
 
         begin_msg = os.linesep.join(begin_msg_lines)
 
@@ -269,25 +296,29 @@ class Tasking:
             Formats the tasking 'FINALIZE' log message.
         """
 
+        start_fmt = format_datetime_with_fractional(self._result.start)
+        stop_fmt = format_datetime_with_fractional(self._result.stop)
+
         finalize_msg_lines = [
             "------------------------------- TASKING FINALIZED -------------------------------"
-            f"    TASK_NAME: {self._result.task_name}",
-            f"      TASK_ID: {self._result.task_id}",
-            f"    PARENT_ID: {self._result.parent_id}",
+            f"    TASK_NAME: {self._result.name}",
+            f"      TASK_ID: {self._result.inst_id}",
+            f"    PARENT_ID: {self._result.parent_inst}",
             f"       LOGDIR: {self._logdir}",
-            f"        START: {self._result.start}",
-            f"         STOP: {self._result.stop}",
+            f"        START: {start_fmt}",
+            f"         STOP: {stop_fmt}",
             f"  RESULT_CODE: {self._result.result_code}",
         ]
 
-        if self._result.exception is None:
-            finalize_msg_lines.append(f"    EXCEPTION: None")
-        else:
-            finalize_msg_lines.append(f"    EXCEPTION: ")
+        finalize_msg_lines.append("ERRORS:")
+        for err in self._result.errors:
+            finalize_msg_lines.extend(indent_lines_list(format_traceback_detail(err), 1))
+            finalize_msg_lines.append("")
 
-            xcpt_lines = traceback.format_exception(self._result.exception)
-            xcpt_lines = indent_lines(xcpt_lines, level=1, indent=10)
-            finalize_msg_lines.append(xcpt_lines)
+        finalize_msg_lines.append("FAILURES:")
+        for fail in self._result.failures:
+            finalize_msg_lines.extend(indent_lines_list(format_traceback_detail(fail), 1))
+            finalize_msg_lines.append("")
 
         finalize_msg = os.linesep.join(finalize_msg_lines)
 
@@ -299,10 +330,10 @@ class Tasking:
         """
         prog_msg_lines = ["PROGRESS"]
 
-        progress_lines = pformat(progress, indent=4, width=200)
-        progress_lines = indent_lines(progress_lines, level=1, indent=4)
+        progress_lines = pformat(progress, indent=4, width=200).splitlines(False)
+        progress_lines = indent_lines_list(progress_lines, level=1, indent=4)
 
-        prog_msg_lines.append(progress_lines)
+        prog_msg_lines.extend(progress_lines)
 
         prog_msg = os.linesep.join(prog_msg_lines)
 
@@ -328,8 +359,9 @@ class Tasking:
             "name": self.full_name,
             "type": this_type.__name__,
             "module": this_type.__module__,
-            "id": self._result.task_id,
-            "parent": self._result.parent_id,
+            "id": self._result.inst_id,
+            "parent": self._result.parent_inst,
+            "worker": self._worker,
             "start": self._result.start,
             "stop": None,
             "status": str(ProgressCode.Running.value),
@@ -340,20 +372,40 @@ class Tasking:
 
         return
 
-    def mark_errored(self):
+    def mark_errored(self, err: BaseException):
         """
             Marks the tasking as having errored.  This indicates to the TaskingServer that shutdown of the
             tasking has begun.
         """
+        tbdetail = create_traceback_detail(err)
+
+        errmsg = format_traceback_detail(tbdetail)
+        self._logger.error(errmsg)
+
+        self._result.add_error(tbdetail)
+    
         self.mark_progress_errored()
         self._progress_queue.put_nowait(self._current_progress)
         return
 
+    def mark_failed(self, err: BaseException):
+        tbdetail = create_traceback_detail(err)
+
+        errmsg = format_traceback_detail(tbdetail)
+        self._logger.error(errmsg)
+
+        self._result.add_failure(tbdetail)
+
+        self.mark_progress_failed()
+        self._progress_queue.put_nowait(self._current_progress)
+        return
+
     def mark_progress_complete(self):
         """
             The `mark_progress_complete` method is called to generate a :class:`ProgressInfo` completed.
         """
         self._task_status = ProgressCode.Completed
+        self._current_progress.when = datetime.now()
         self._current_progress.status = ProgressCode.Completed
         return
 
@@ -362,14 +414,25 @@ class Tasking:
             The `mark_progress_errored` method is called to generate a :class:`ProgressInfo` errored.
         """
         self._task_status = ProgressCode.Errored
+        self._current_progress.when = datetime.now()
         self._current_progress.status = ProgressCode.Errored
         return
     
+    def mark_progress_failed(self):
+        """
+            The `mark_progress_failed` method is called to generate a :class:`ProgressInfo` failed.
+        """
+        self._task_status = ProgressCode.Failed
+        self._current_progress.when = datetime.now()
+        self._current_progress.status = ProgressCode.Failed
+        return
+
     def mark_progress_paused(self):
         """
             The `mark_progress_paused` method is called to generate a :class:`ProgressInfo` paused.
         """
         self._task_status = ProgressCode.Paused
+        self._current_progress.when = datetime.now()
         self._current_progress.status = ProgressCode.Paused
         return
     
@@ -378,6 +441,7 @@ class Tasking:
             The `mark_progress_running` method is called to generate a :class:`ProgressInfo` running.
         """
         self._task_status = ProgressCode.Running
+        self._current_progress.when = datetime.now()
         self._current_progress.status = ProgressCode.Running
         return
 
@@ -386,7 +450,8 @@ class Tasking:
             The `mark_progress_start` method that is called to generate a :class:`ProgressInfo` running.
         """
         self._task_status = ProgressCode.Running
-        self._current_progress = ProgressInfo(self._task_id, ProgressType.NumericRange, self.full_name, 0, 0, 0, ProgressCode.Running, {})
+        self._current_progress = ProgressInfo(self._tasking_id, ProgressType.NumericRange, self.full_name,
+                                              0, 0, 0, ProgressCode.Running, datetime.now(), {})
         return
 
     def notify_progress(self, progress: ProgressInfo):
@@ -462,6 +527,7 @@ class Tasking:
             does not trigger an inactivity timeout shutdown of the tasking.
         """
 
+        self._current_progress.when = datetime.now()
         prog_dict = self._current_progress.as_dict()
 
         prog_msg = self.format_progress_message(prog_dict)
@@ -510,18 +576,22 @@ class Tasking:
         # Update our local in process copy of these queues, because we have forked
         self._progress_queue = progress_queue
 
-        self._result = TaskingResult(self.full_name, self._task_id, self._logdir, parent_id=self._parent_id)
+        prefix = self.PREFIX
+
+        self._logger.info(f"Starting thread for tasking name={self.full_name} tasking_id={self._tasking_id}")
+
+        self._result = self.create_tasking_result(self._tasking_id, self.full_name, self._parent_id, prefix)
         self._running = True
 
-        self.initialize_summary()
-        self.initialize_metrics()
-
-        sgate.set()
-
-        self.begin(kwparams)
-
         try:
 
+            self.initialize_summary()
+            self.initialize_metrics()
+
+            sgate.set()
+
+            self.begin(kwparams)
+
             try:
 
                 try:
@@ -554,56 +624,27 @@ class Tasking:
                     else:
                         self.mark_progress_complete()
 
+                    # Evaluate results should raise an AssertionError if the tasking failed
+                    # to successfully complete its tasking.
+                    self.evaluate_results()
+
                     self.submit_progress()
-
-                except Exception as innererr:
-                    self._exception = innererr
-
-                    self.mark_errored()
-
-                finally:
-                    self._result_code = self.evaluate_results()
+                except AssertionError as aerr:
+                    self.mark_failed(aerr)
+                except Exception as gerr:
+                    self.mark_errored(gerr)
 
             except Exception as evalerr:
-                if self._result_code is None:
-                    self._result_code = -999
-
-                if self._exception is not None:
-                    try:
-                        raise evalerr from self._exception
-                    except Exception as comberr:
-                        self._exception = comberr
-                else:
-                    self._exception = evalerr
-
-                self.mark_errored()
+                self.mark_errored(evalerr)
 
             # We still need to attempt to cleanup
             self.cleanup()
 
-        except Exception as finalerr:
-            if self._result_code is None:
-                    self._result_code = -888
-
-            if self._exception is not None:
-                try:
-                    raise finalerr from self._exception
-                except Exception as comberr:
-                    self._exception = comberr
-            else:
-                self._exception = finalerr
-
-            self.mark_errored()
+        except BaseException as finalerr:
+            self.mark_errored(finalerr)
 
         finally:
-            self._result.mark_result(self._result_code, self._exception)
-            self._summary["stop"] = self._result.stop
-
-            try:
-                self.finalize()
-            except Exception as xcpt:
-                errmsg = traceback.format_exception(xcpt)
-                self._logger.error(errmsg)
+            self.finalize()
 
             self._running = False
 
